NML documentation

# Additional references

## Animation speed

House, industry and airport tiles can define an animation speed. This property gives the animation speed in ticks, spaced by powers of two. For houses the minimum value is 2 (=4 ticks). The ingame length as well real length is given as rounded values for reference only, assuming normal game speed.

value | animation length in ticks | ingame | real time
--- | --- | --- | ---
0 | 1 |  | 0.03 s
1 | 2 |  | 0.06 s
2 | 4 |  | 0.11 s
3 | 8 |  | 0.22 s
4 | 16 |  | 0.45 s
5 | 32 | half a day | 0.9 s
6 | 64 | nearly 1 day | 1.8 s
7 | 128 | 2 days | 3½ s
8 | 256 | 3½ days | 7 s
9 | 512 | 7 days | 15 s
10 | 1024 | 14 days | 30 s
11 | 2048 | 28 days | 1 min
12 | 4096 | 55 days | 2 min
13 | 8192 | 3½ months | 4 min
14 | 16384 | 7½ months | 7½ min
15 | 32768 | 15 months | 15 min
16 | 65536 | 2½ years | 30 min

## Default industries

- INDUSTRYTYPE_COAL_MINE
- INDUSTRYTYPE_POWER_PLANT
- INDUSTRYTYPE_SAWMILL
- INDUSTRYTYPE_FOREST
- INDUSTRYTYPE_OIL_REFINERY
- INDUSTRYTYPE_OIL_RIG
- INDUSTRYTYPE_TEMPERATE_FACTORY
- INDUSTRYTYPE_TROPICAL_FACTORY
- INDUSTRYTYPE_PRINTING_WORKS
- INDUSTRYTYPE_STEEL_MILL
- INDUSTRYTYPE_TEMPERATE_ARCTIC_FARM
- INDUSTRYTYPE_TROPICAL_FARM
- INDUSTRYTYPE_COPPER_ORE_MINE
- INDUSTRYTYPE_OIL_WELLS
- INDUSTRYTYPE_FOOD_PROCESSING_PLANT
- INDUSTRYTYPE_PAPER_MILL
- INDUSTRYTYPE_TEMPERATE_BANK
- INDUSTRYTYPE_TROPICAL_ARCTIC_BANK
- INDUSTRYTYPE_GOLD_MINE
- INDUSTRYTYPE_DIAMOND_MINE
- INDUSTRYTYPE_IRON_ORE_MINE
- INDUSTRYTYPE_FRUIT_PLANTATION
- INDUSTRYTYPE_RUBBER_PLANTATION
- INDUSTRYTYPE_WATER_WELL
- INDUSTRYTYPE_WATER_TOWER
- INDUSTRYTYPE_LUMBER_MILL
- INDUSTRYTYPE_CANDYFLOSS_FOREST
- INDUSTRYTYPE_SWEETS_FACTORY
- INDUSTRYTYPE_BATTERY_FARM
- INDUSTRYTYPE_COLA_WELLS
- INDUSTRYTYPE_TOY_SHOP
- INDUSTRYTYPE_TOY_FACTORY
- INDUSTRYTYPE_PLASTIC_FOUNTAIN
- INDUSTRYTYPE_FIZZY_DRINKS_FACTORY
- INDUSTRYTYPE_BUBBLE_GENERATOR
- INDUSTRYTYPE_TOFFE_QUARRY
- INDUSTRYTYPE_SUGAR_MINE

- INDUSTRYTYPE_UNKNOWN
- INDUSTRYTYPE_TOWN

## Default industry tiles

00..06 | coal mine
07..10 | power station
11..15 | sawmill
16..17 | forest
18..23 | oil refinery
24..28 | oil rig
29..32 | oil wells
33..38 | farm
39..42 | factory (temperate climate)
43..45 | printing works
47..51 | copper ore mine
52..57 | steel mill
58..59 | bank (temperate climate)
60..63 | food processing plant
64..71 | paper mill
72..88 | gold mine
89..90 | bank (sub-arctic or sub-tropical climate)
91..99 | diamond mine
100..115 | iron ore mine
116 | fruit plantation
117 | rubber plantation
118..119 | water supply
120 | water tower
121..124 | factory (sub-tropical climate)
125..128 | lumber mill
129..130 | candyfloss forest
131..134 | sweet factory
135..136 | battery farm
137 | cola wells
138..141 | toy shop
142..147 | toy factory
148..155 | plastic fountains (various stages of cyclic animation)
156..159 | fizzy drink factory
160..163 | bubble generator
164..166 | toffee quarry
167..174 | sugar mine

## Base cost table

Number | Identifier | Category | Default value | Version | Remarks
--- | --- | --- | --- | --- | ---
0 | PR_STATION_VALUE | - | 100 |  | Used for some misc. purposes
1 | PR_BUILD_RAIL | PR_CONSTRUCTION | 100 |  |
2 | PR_BUILD_ROAD | PR_CONSTRUCTION | 95 |  |
3 | PR_BUILD_SIGNALS | PR_CONSTRUCTION | 65 |  |
4 | PR_BUILD_BRIDGE | PR_CONSTRUCTION | 275 |  |
5 | PR_BUILD_DEPOT_TRAIN | PR_CONSTRUCTION | 600 |  | Affects PR_BUILD_WAYPOINT_RAIL (*)
6 | PR_BUILD_DEPOT_ROAD | PR_CONSTRUCTION | 500 |  |
7 | PR_BUILD_DEPOT_SHIP | PR_CONSTRUCTION | 700 |  |
8 | PR_BUILD_TUNNEL | PR_CONSTRUCTION | 450 |  |
9 | PR_BUILD_STATION_RAIL | PR_CONSTRUCTION | 200 |  | Cost per tile
10 | PR_BUILD_STATION_RAIL_LENGTH | PR_CONSTRUCTION | 180 |  | Cost per platform (*)
11 | PR_BUILD_STATION_AIRPORT | PR_CONSTRUCTION | 600 |  |
12 | PR_BUILD_STATION_BUS | PR_CONSTRUCTION | 200 |  |
13 | PR_BUILD_STATION_TRUCK | PR_CONSTRUCTION | 200 |  |
14 | PR_BUILD_STATION_DOCK | PR_CONSTRUCTION | 350 |  | Affects PR_BUILD_WAYPOINT_BUOY (*)
15 | PR_BUILD_VEHICLE_TRAIN | PR_BUILD_VEHICLE | 400000 |  | (**)
16 | PR_BUILD_VEHICLE_WAGON | PR_BUILD_VEHICLE | 2000 |  | (**)
17 | PR_BUILD_VEHICLE_AIRCRAFT | PR_BUILD_VEHICLE | 700000 |  | (**)
18 | PR_BUILD_VEHICLE_ROAD | PR_BUILD_VEHICLE | 14000 |  | (**)
19 | PR_BUILD_VEHICLE_SHIP | PR_BUILD_VEHICLE | 65000 |  | (**)
20 | PR_BUILD_TREES | PR_CONSTRUCTION | 20 |  |
21 | PR_TERRAFORM | PR_CONSTRUCTION | 250 |  | Affects PR_BUILD_FOUNDATION (*)
22 | PR_CLEAR_GRASS | PR_CONSTRUCTION | 20 |  |
23 | PR_CLEAR_ROUGH | PR_CONSTRUCTION | 40 |  | Affects PR_*_UNMOVABLE (*)
24 | PR_CLEAR_ROCKS | PR_CONSTRUCTION | 200 |  |
25 | PR_CLEAR_FIELDS | PR_CONSTRUCTION | 500 |  |
26 | PR_CLEAR_TREES | PR_CONSTRUCTION | 20 |  |
27 | PR_CLEAR_RAIL | PR_CONSTRUCTION | -70 |  |
28 | PR_CLEAR_SIGNALS | PR_CONSTRUCTION | 10 |  |
29 | PR_CLEAR_BRIDGE | PR_CONSTRUCTION | 50 |  | Affects PR_CLEAR_AQUEDUCT (*)
30 | PR_CLEAR_DEPOT_TRAIN | PR_CONSTRUCTION | 80 |  | Affects PR_CLEAR_WAYPOINT_RAIL (*)
31 | PR_CLEAR_DEPOT_ROAD | PR_CONSTRUCTION | 80 |  |
32 | PR_CLEAR_DEPOT_SHIP | PR_CONSTRUCTION | 90 |  |
33 | PR_CLEAR_TUNNEL | PR_CONSTRUCTION | 30 |  |
34 | PR_CLEAR_WATER | PR_CONSTRUCTION | 10000 |  | Affects PR_*_CANAL, PR_*_LOCK and PR_BUILD_AQUEDUCT (*)
35 | PR_CLEAR_STATION_RAIL | PR_CONSTRUCTION | 50 |  |
36 | PR_CLEAR_STATION_AIRPORT | PR_CONSTRUCTION | 30 |  |
37 | PR_CLEAR_STATION_BUS | PR_CONSTRUCTION | 50 |  |
38 | PR_CLEAR_STATION_TRUCK | PR_CONSTRUCTION | 50 |  | Affects PR_CLEAR_WAYPOINT_BUOY (*)
39 | PR_CLEAR_STATION_DOCK | PR_CONSTRUCTION | 55 |  |
40 | PR_CLEAR_HOUSE | PR_CONSTRUCTION | 1600 |  | Affects PR_CLEAR_INDUSTRY (*)
41 | PR_CLEAR_ROAD | PR_CONSTRUCTION | 40 |  |
42 | PR_RUNNING_TRAIN_STEAM | PR_RUNNING | 5600 |  | (**)
43 | PR_RUNNING_TRAIN_DIESEL | PR_RUNNING | 5200 |  | (**)
44 | PR_RUNNING_TRAIN_ELECTRIC | PR_RUNNING | 4800 |  | (**)
45 | PR_RUNNING_AIRCRAFT | PR_RUNNING | 9600 |  | (**)
46 | PR_RUNNING_ROADVEH | PR_RUNNING | 1600 |  | (**)
47 | PR_RUNNING_SHIP | PR_RUNNING | 5600 |  | (**)
48 | PR_BUILD_INDUSTRY | PR_CONSTRUCTION | 1000000 |  | Affects PR_TOWN_ACTION, PR_BUILD_INDUSTRY_RAW and PR_BUILD_TOWN (*)
49 | PR_CLEAR_INDUSTRY | PR_CONSTRUCTION | 1600 | OTTD r18283 | Affected by PR_CLEAR_HOUSE (*)
50 | PR_BUILD_UNMOVABLE | PR_CONSTRUCTION | 40 | OTTD r18283 | Affected by PR_CLEAR_ROUGH (*)
51 | PR_CLEAR_UNMOVABLE | PR_CONSTRUCTION | 40 | OTTD r18283 | Affected by PR_CLEAR_ROUGH (*)
52 | PR_BUILD_WAYPOINT_RAIL | PR_CONSTRUCTION | 600 | OTTD r18283 | Affected by PR_BUILD_DEPOT_TRAIN (*)
53 | PR_CLEAR_WAYPOINT_RAIL | PR_CONSTRUCTION | 80 | OTTD r18283 | Affected by PR_CLEAR_DEPOT_TRAIN (*)
54 | PR_BUILD_WAYPOINT_BUOY | PR_CONSTRUCTION | 350 | OTTD r18283 | Affected by PR_BUILD_STATION_DOCK (*)
55 | PR_CLEAR_WAYPOINT_BUOY | PR_CONSTRUCTION | 50 | OTTD r18283 | Affected by PR_CLEAR_WAYPOINT_BUOY (*)
56 | PR_TOWN_ACTION | PR_CONSTRUCTION | 1000000 | OTTD r18283 | Interactions with local authority, affected by PR_BUILD_INDUSTRY (*)
57 | PR_BUILD_FOUNDATION | PR_CONSTRUCTION | 250 | OTTD r18283 | Affected by PR_BUILD_FOUNDATION (*)
58 | PR_BUILD_INDUSTRY_RAW | PR_CONSTRUCTION | 8000000 | OTTD r18283 | Directly building (not prospecting) raw industries, affected by PR_BUILD_INDUSTRY (*)
59 | PR_BUILD_TOWN | PR_CONSTRUCTION | 1000000 | OTTD r18283 | Affected by PR_BUILD_INDUSTRY (*)
60 | PR_BUILD_CANAL | PR_CONSTRUCTION | 5000 | OTTD r19720 | Affected by PR_CLEAR_WATER (*)
61 | PR_CLEAR_CANAL | PR_CONSTRUCTION | 5000 | OTTD r19720 | Affected by PR_CLEAR_WATER (*)
62 | PR_BUILD_AQUEDUCT | PR_CONSTRUCTION | 10000 | OTTD r19720 | Affected by PR_CLEAR_WATER (*)
63 | PR_CLEAR_AQUEDUCT | PR_CONSTRUCTION | 2000 | OTTD r19720 | Affected by PR_CLEAR_BRIDGE (*)
64 | PR_BUILD_LOCK | PR_CONSTRUCTION | 7500 | OTTD r19720 | Affected by PR_CLEAR_WATER (*)
65 | PR_CLEAR_LOCK | PR_CONSTRUCTION | 2000 | OTTD r19720 | Affected by PR_CLEAR_WATER (*)

(*) Recent OpenTTD versions have added a number of base costs. To keep compatibility with earlier grfs, a number of 'old' base costs override the 'new' ones if the 'new' costs are not set separately. These cases are marked in the table. To avoid this behaviour always set the 'new' cost to 0 if you are changing the 'old' cost but want to keep the new one unchanged. Note that this may override other grfs that change base costs, but this is currently unavoidable.

(**) In TTDPatch and OpenTTD before r18268, setting these costs affects all vehicles. In OpenTTD after r18268, they apply only to vehicles defined by the grf, if said grf defines any vehicles of the related type itself. Else, they have an effect on all vehicles of the appropriate type.

## List of sound effects

- SOUND_SPLAT
- SOUND_FACTORY_WHISTLE
- SOUND_TRAIN
- SOUND_TRAIN_THROUGH_TUNNEL
- SOUND_SHIP_HORN
- SOUND_FERRY_HORN
- SOUND_PLANE_TAKE_OFF
- SOUND_JET
- SOUND_TRAIN_HORN
- SOUND_MINING_MACHINERY
- SOUND_ELECTRIC_SPARK
- SOUND_STEAM
- SOUND_LEVEL_CROSSING
- SOUND_VEHICLE_BREAKDOWN
- SOUND_TRAIN_BREAKDOWN
- SOUND_CRASH
- SOUND_EXPLOSION
- SOUND_BIG_CRASH
- SOUND_CASHTILL
- SOUND_BEEP
- SOUND_MORSE
- SOUND_SKID_PLANE
- SOUND_HELICOPTER
- SOUND_BUS_START_PULL_AWAY
- SOUND_BUS_START_PULL_AWAY_WITH_HORN
- SOUND_TRUCK_START
- SOUND_TRUCK_START_2
- SOUND_APPLAUSE
- SOUND_OOOOH
- SOUND_SPLAT
- SOUND_SPLAT_2
- SOUND_JACKHAMMER
- SOUND_CAR_HORN
- SOUND_CAR_HORN_2
- SOUND_SHEEP
- SOUND_COW
- SOUND_HORSE
- SOUND_BLACKSMITH_ANVIL
- SOUND_SAWMILL
- SOUND_GOOD_YEAR
- SOUND_BAD_YEAR
- SOUND_RIP
- SOUND_EXTRACT_AND_POP
- SOUND_COMEDY_HIT
- SOUND_MACHINERY
- SOUND_RIP_2
- SOUND_EXTRACT_AND_POP
- SOUND_POP
- SOUND_CARTOON_SOUND
- SOUND_EXTRACT
- SOUND_POP_2
- SOUND_PLASTIC_MINE
- SOUND_WIND
- SOUND_COMEDY_BREAKDOWN
- SOUND_CARTOON_CRASH
- SOUND_BALLOON_SQUEAK
- SOUND_CHAINSAW
- SOUND_HEAVY_WIND
- SOUND_COMEDY_BREAKDOWN_2
- SOUND_JET_OVERHEAD
- SOUND_COMEDY_CAR
- SOUND_ANOTHER_JET_OVERHEAD
- SOUND_COMEDY_CAR_2
- SOUND_COMEDY_CAR_3
- SOUND_COMEDY_CAR_START_AND_PULL_AWAY
- SOUND_MAGLEV
- SOUND_LOON_BIRD
- SOUND_LION
- SOUND_MONKEYS
- SOUND_PLANE_CRASHING
- SOUND_PLANE_ENGINE_SPUTTERING
- SOUND_MAGLEV_2
- SOUND_DISTANT_BIRD

## List of default vehicle IDs

### List of default rail engines

Number | Name | weight (ton) | cargo_capacity | cost_factor | speed (km/h) | power (hp) | running_cost_factor | climates
--- | --- | --- | --- | --- | --- | --- | --- | ---
0 | Kirby Paul Tank (Steam) | 47 | 0 | 7 | 64 | 300 | 50 | Temperate
1 | MJS 250 (Diesel) | 65 | 0 | 8 | 80 | 600 | 65 | Arctic, Tropical
2 | Ploddyphut Choo-Choo | 90 | 0 | 10 | 72 | 400 | 90 | Toyland
3 | Powernaut Choo-Choo | 130 | 0 | 15 | 96 | 900 | 130 | Toyland
4 | Mightymover Choo-Choo | 140 | 0 | 19 | 112 | 1000 | 145 | Toyland
5 | Ploddyphut Diesel | 95 | 0 | 16 | 120 | 1400 | 125 | Toyland
6 | Powernaut Diesel | 120 | 0 | 20 | 152 | 2000 | 135 | Toyland
7 | Wills 2-8-0 (Steam) | 145 | 0 | 14 | 88 | 1100 | 130 | Arctic, Tropical
8 | Chaney 'Jubilee' (Steam) | 131 | 0 | 13 | 112 | 1000 | 120 | Temperate
9 | Ginzu 'A4' (Steam) | 162 | 0 | 19 | 128 | 1200 | 140 | Temperate
10 | SH '8P' (Steam) | 170 | 0 | 22 | 144 | 1600 | 130 | Temperate
11 | Manley-Morel DMU (Diesel) | 32 | 38 | 11 | 112 | 600 | 85 | Temperate
12 | 'Dash' (Diesel) | 38 | 40 | 14 | 120 | 700 | 70 | Temperate
13 | SH/Hendry '25' (Diesel) | 72 | 0 | 15 | 128 | 1250 | 95 | Temperate
14 | UU '37' (Diesel) | 101 | 0 | 17 | 144 | 1750 | 120 | Temperate
15 | Floss '47' (Diesel) | 112 | 0 | 18 | 160 | 2580 | 140 | Temperate
16 | CS 4000 (Diesel) | 150 | 0 | 23 | 96 | 4000 | 135 | Arctic, Tropical
17 | CS 2400 (Diesel) | 120 | 0 | 16 | 112 | 2400 | 105 | Arctic, Tropical
18 | Centennial (Diesel) | 207 | 0 | 30 | 112 | 6600 | 155 | Arctic, Tropical
19 | Kelling 3100 (Diesel) | 110 | 0 | 18 | 104 | 1500 | 105 | Arctic, Tropical
20 | Turner Turbo (Diesel) | 95 | 0 | 35 | 160 | 3500 | 205 | Arctic, Tropical
21 | MJS 1000 (Diesel) | 120 | 0 | 21 | 104 | 2200 | 145 | Arctic, Tropical
22 | SH '125' (Diesel) | 70 | 4 | 20 | 200 | 4500 | 190 | Temperate
23 | SH '30' (Electric) | 84 | 0 | 26 | 160 | 3600 | 180 | Temperate
24 | SH '40' (Electric) | 82 | 0 | 30 | 176 | 5000 | 205 | Temperate
25 | 'T.I.M.' (Electric) | 90 | 0 | 40 | 240 | 7000 | 240 | Temperate
26 | 'AsiaStar' (Electric) | 95 | 0 | 43 | 264 | 8000 | 250 | Temperate

### List of default rail wagons

Number | Name | weight (ton) | cargo_capacity | cost_factor
--- | --- | --- | --- | ---
27 | Passenger Carriage | 25 | 40 | 247
28 | Mail Van | 21 | 30 | 228
29 | Coal Truck | 18 | 30 | 176
30 | Oil Tanker | 24 | 30 | 200
31 | Livestock Van | 20 | 25 | 192
32 | Goods Van | 21 | 25 | 190
33 | Grain Hopper | 19 | 30 | 182
34 | Wood Truck | 16 | 30 | 181
35 | Iron Ore Hopper | 19 | 30 | 179
36 | Steel Truck | 18 | 20 | 196
37 | Armoured Van | 30 | 20 | 255
38 | Food Van | 22 | 25 | 191
39 | Paper Truck | 18 | 20 | 196
40 | Copper Ore Hopper | 19 | 30 | 179
41 | Water Tanker | 25 | 25 | 199
42 | Fruit Truck | 18 | 25 | 182
43 | Rubber Truck | 19 | 21 | 185
44 | Sugar Truck | 19 | 30 | 176
45 | Candyfloss Hopper | 20 | 30 | 178
46 | Toffee Hopper | 20 | 30 | 192
47 | Bubble Van | 21 | 20 | 190
48 | Cola Tanker | 24 | 25 | 182
49 | Sweet Van | 21 | 25 | 181
50 | Toy Van | 21 | 20 | 183
51 | Battery Truck | 18 | 22 | 196
52 | Fizzy Drink Truck | 18 | 25 | 193
53 | Plastic Truck | 18 | 30 | 191

### List of default monorail engines

Number | Name | weight (ton) | cargo_capacity | cost_factor | speed (km/h) | power (hp) | running_cost_factor | climates
--- | --- | --- | --- | --- | --- | --- | --- | ---
54 | 'X2001' (Electric) | 95 | 0 | 52 | 304 | 9000 | 230 | Temperate
55 | 'Millennium Z1' (Electric) | 85 | 25 | 60 | 336 | 10000 | 240 | Temperate
56 | Wizzowow Z99 | 95 | 0 | 53 | 320 | 5000 | 230 | Toyland

### List of default monorail wagons

Number | Name | weight (ton) | cargo_capacity | cost_factor
--- | --- | --- | --- | ---
57 | Passenger Carriage | 25 | 45 | 247
58 | Mail Van | 21 | 35 | 228
59 | Coal Truck | 18 | 35 | 176
60 | Oil Tanker | 24 | 35 | 200
61 | Livestock Van | 20 | 30 | 192
62 | Goods Van | 21 | 30 | 190
63 | Grain Hopper | 19 | 35 | 182
64 | Wood Truck | 16 | 35 | 181
65 | Iron Ore Hopper | 19 | 35 | 179
66 | Steel Truck | 18 | 25 | 196
67 | Armoured Van | 30 | 25 | 255
68 | Food Van | 22 | 30 | 192
69 | Paper Truck | 18 | 25 | 196
70 | Copper Ore Hopper | 19 | 35 | 179
71 | Water Tanker | 25 | 30 | 199
72 | Fruit Truck | 18 | 30 | 182
73 | Rubber Truck | 19 | 26 | 185
74 | Sugar Truck | 19 | 25 | 176
75 | Candyfloss Hopper | 20 | 35 | 178
76 | Toffee Hopper | 20 | 35 | 192
77 | Bubble Van | 21 | 25 | 190
78 | Cola Tanker | 24 | 30 | 182
79 | Sweet Van | 21 | 30 | 181
80 | Toy Van | 21 | 25 | 183
81 | Battery Truck | 18 | 27 | 196
82 | Fizzy Drink Truck | 18 | 30 | 193
83 | Plastic Truck | 18 | 35 | 191

### List of default maglev engines

Number | Name | weight (ton) | cargo_capacity | cost_factor | speed (km/h) | power (hp) | running_cost_factor | climates
--- | --- | --- | --- | --- | --- | --- | --- | ---
84 | Lev1 'Leviathan' (Electric) | 105 | 0 | 70 | 400 | 10000 | 250 | Temperate
85 | Lev2 'Cyclops' (Electric) | 120 | 0 | 74 | 448 | 12000 | 253 | Temperate
86 | Lev3 'Pegasus' (Electric) | 130 | 0 | 82 | 480 | 15000 | 254 | Temperate
87 | Lev4 'Chimaera' (Electric) | 150 | 0 | 95 | 640 | 20000 | 255 | Temperate
88 | Wizzowow Rocketeer | 120 | 0 | 70 | 480 | 10000 | 250 | Toyland

### List of default maglev wagons

Number | Name | weight (ton) | cargo_capacity | cost_factor
--- | --- | --- | --- | ---
89 | Passenger Carriage | 25 | 47 | 247
90 | Mail Van | 21 | 37 | 228
91 | Coal Truck | 18 | 37 | 176
92 | Oil Tanker | 24 | 37 | 200
93 | Livestock Van | 20 | 32 | 192
94 | Goods Van | 21 | 32 | 190
95 | Grain Hopper | 19 | 37 | 182
96 | Wood Truck | 16 | 37 | 181
97 | Iron Ore Hopper | 19 | 37 | 179
98 | Steel Truck | 18 | 27 | 196
99 | Armoured Van | 30 | 27 | 255
100 | Food Van | 22 | 32 | 191
101 | Paper Truck | 18 | 27 | 196
102 | Copper Ore Hopper | 19 | 37 | 179
103 | Water Tanker | 25 | 32 | 199
104 | Fruit Truck | 18 | 32 | 182
105 | Rubber Truck | 19 | 28 | 185
106 | Sugar Truck | 19 | 37 | 176
107 | Candyfloss Hopper | 20 | 37 | 178
108 | Toffee Hopper | 20 | 37 | 192
109 | Bubble Van | 21 | 27 | 190
110 | Cola Tanker | 24 | 32 | 182
111 | Sweet Van | 21 | 32 | 181
112 | Toy Van | 21 | 27 | 183
113 | Battery Truck | 18 | 29 | 196
114 | Fizzy Drink Truck | 18 | 32 | 193
115 | Plastic Truck | 18 | 37 | 191

### List of default busses

Number | Name
--- | ---
00 | MPS Regal Bus
01 | Hereford Leopard Bus
02 | Foster Bus
03 | Foster MkII Superbus
04 | Ploddyphut MkI Bus
05 | Ploddyphut MkII Bus
06 | Ploddyphut MkIII Bus

### List of default trucks

Number | Name
--- | ---
07 | Balogh Coal Truck
08 | Uhl Coal Truck
09 | DW Coal Truck
10 | MPS Mail Truck
11 | Reynard Mail Truck
12 | Perry Mail Truck
13 | MightyMover Mail Truck
14 | Powernaught Mail Truck
15 | Wizzowow Mail Truck
16 | Witcombe Oil Tanker
17 | Foster Oil Tanker
18 | Perry Oil Tanker
19 | Talbott Livestock Van
20 | Uhl Livestock Van
21 | Foster Livestock Van
22 | Balogh Goods Truck
23 | Craighead Goods Truck
24 | Goss Goods Truck
25 | Hereford Grain Truck
26 | Thomas Grain Truck
27 | Goss Grain Truck
28 | Witcombe Wood Truck
29 | Foster Wood Truck
30 | Moreland Wood Truck
31 | MPS Iron Ore Truck
32 | Uhl Iron Ore Truck
33 | Chippy Iron Ore Truck
34 | Balogh Steel Truck
35 | Uhl Steel Truck
36 | Kelling Steel Truck
37 | Balogh Armoured Truck
38 | Uhl Armoured Truck
39 | Foster Armoured Truck
40 | Foster Food Van
41 | Perry Food Van
42 | Chippy Food Van
43 | Uhl Paper Truck
44 | Balogh Paper Truck
45 | MPS Paper Truck
46 | MPS Copper Ore Truck
47 | Uhl Copper Ore Truck
48 | Goss Copper Ore Truck
49 | Uhl Water Tanker
50 | Balogh Water Tanker
51 | MPS Water Tanker
52 | Balogh Fruit Truck
53 | Uhl Fruit Truck
54 | Kelling Fruit Truck
55 | Balogh Rubber Truck
56 | Uhl Rubber Truck
57 | RMT Rubber Truck
58 | MightyMover Sugar Truck
59 | Powernaught Sugar Truck
60 | Wizzowow Sugar Truck
61 | MightyMover Cola Truck
62 | Powernaught Cola Truck
63 | Wizzowow Cola Truck
64 | MightyMover Candyfloss Truck
65 | Powernaught Candyfloss Truck
66 | Wizzowow Candyfloss Truck
67 | MightyMover Toffee Truck
68 | Powernaught Toffee Truck
69 | Wizzowow Toffee Truck
70 | MightyMover Toy Van
71 | Powernaught Toy Van
72 | Wizzowow Toy Van
73 | MightyMover Sweet Lorry
74 | Powernaught Sweet Lorry
75 | Wizzowow Sweet Lorry
76 | MightyMover Battery Truck
77 | Powernaught Battery Truck
78 | Wizzowow Battery Truck
79 | MightyMover Fizzy Drink Truck
80 | Powernaught Fizzy Drink Truck
81 | Wizzowow Fizzy Drink Truck
82 | MightyMover Plastic Truck
83 | Powernaught Plastic Truck
84 | Wizzowow Plastic Truck
85 | MightyMover Bubble Truck
86 | Powernaught Bubble Truck
87 | Wizzowow Bubble Truck

### List of default ships

Number | Name
--- | ---
0 | MPS Oil Tanker
1 | CS-Inc. Oil Tanker
2 | MPS Passenger Ferry
3 | FFP Passenger Ferry
4 | Bakewell 300 Hovercraft
5 | Chugger-Chug Passenger Ferry
6 | Shivershake Passenger Ferry
7 | Yate Cargo ship
8 | Bakewell Cargo ship
9 | Mightymover Cargo ship
10 | Powernaut Cargo ship

### List of default planes

Number | Name
--- | ---
00 | Sampson U52
01 | Coleman Count
02 | FFP Dart
03 | Yate Haugan
04 | Bakewell Cotswald LB-3
05 | Bakewell Luckett LB-8
06 | Bakewell Luckett LB-9
07 | Bakewell Luckett LB80
08 | Bakewell Luckett LB-10
09 | Bakewell Luckett LB-11
10 | Yate Aerospace YAC 1-11
11 | Darwin 100
12 | Darwin 200
13 | Darwin 300
14 | Darwin 400
15 | Darwin 500
16 | Darwin 600
17 | Guru Galaxy
18 | Airtaxi A21
19 | Airtaxi A31
20 | Airtaxi A32
21 | Airtaxi A33
22 | Yate Aerospace YAe46
23 | Dinger 100
24 | AirTaxi A34-1000
25 | Yate Z-Shuttle
26 | Kelling K1
27 | Kelling K6
28 | Kelling K7
29 | Darwin 700
30 | FFP Hyperdart 2
31 | Dinger 200
32 | Dinger 1000
33 | Ploddyphut 100
34 | Ploddyphut 500
35 | Flashbang X1
36 | Juggerplane M1
37 | Flashbang Wizzer

### List of default helicopters

Number | Name
--- | ---
38 | Tricario Helicopter
39 | Guru X2 Helicopter
40 | Powernaut Helicopter

## List of default houses and their properties

Number | Name | Climate | Town zones | Flags | Minimum year built | Last year built | Population | Mail generation | Passenger acceptance | Mail acceptance | Goods acceptance | Remove ratings decrease | Remove cost multiplier
00 | tall office block | temperate | CENTRE | SIZE_1x1 | 1963 | none | 187 | 70 | 8 | 3 | 4 | 140 | 150
01 | office block | temperate | INNER_SUBURB, CENTRE | SIZE_1x1 | 1957 | none | 85 | 55 | 8 | 3 | 4 | 130 | 140
02 | small block of flats | temperate | OUTSKIRT .. INNER_SUBURB | SIZE_1x1 | 1968 | none | 40 | 20 | 8 | 3 | 1 | 90 | 100
03 | church | temperate | EDGE ... INNER_SUBURB | SIZE_1x1 | 1930 | none | 5 | 2 | 2 | 0 | 0 | 230 | 90
04 | large office block | temperate, sub-arctic, subtropical | CENTRE | SIZE_1x1, ANIMATE | 1975 | none | 220 | 85 | 10 | 4 | 6 | 160 | 160
05 | large office block | snow | CENTRE | SIZE_1x1, ANIMATE | 1975 | none | 220 | 85 | 10 | 4 | 6 | 160 | 160
06 | town houses | temperate | EDGE ... INNER_SUBURB | SIZE_1x1 | 1930 | none | 30 | 12 | 4 | 1 | 0 | 80 | 80
07 | hotel (N part) | temperate | OUTER_SUBURB, CENTRE | SIZE_1x2 | 1959 | none | 140 | 22 | 6 | 1 | 2 | 150 | 180
08 | hotel (E part) |  |  | N/A | 1959 | none | 0 | 22 | 6 | 1 | 2 | 150 | 180
09 | statue | temperate, sub-arctic, subtropical | INNER_SUBURB, CENTRE | SIZE_1x1 | 1945 | none | 0 | 0 | 2 | 0 | 0 | 40 | 65
10 | fountain | temperate, sub-arctic, subtropical | CENTRE | SIZE_1x1 | 1945 | none | 0 | 0 | 2 | 0 | 0 | 40 | 65
11 | park (with a pond) | temperate | OUTER_SUBURB | SIZE_1x1 | 1930 | none | 0 | 0 | 2 | 0 | 0 | 75 | 60
12 | park (with an alley) | temperate | INNER_SUBURB | SIZE_1x1 | 1935 | none | 0 | 0 | 2 | 0 | 0 | 75 | 60
13 | office block | temperate | INNER_SUBURB, CENTRE | SIZE_1x1 | 1951 | none | 150 | 65 | 8 | 2 | 4 | 110 | 130
14 | shops and offices 1 | temperate | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | 1960 | 95 | 48 | 6 | 2 | 3 | 100 | 110
15 | shops and offices 2 | temperate | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | 1960 | 95 | 48 | 6 | 2 | 3 | 100 | 105
16 | shops and offices 3 | temperate | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | 1960 | 95 | 48 | 6 | 2 | 3 | 100 | 107
17 | modern office building | temperate, sub-arctic, subtropical | CENTRE | SIZE_1x1 | 1977 | none | 130 | 50 | 10 | 3 | 6 | 150 | 200
18 | warehouse | temperate | CENTRE | SIZE_1x1 | 1983 | none | 6 | 10 | 6 | 3 | 8 | 110 | 145
19 | office block (with spiral stairway) | temperate | CENTRE | SIZE_1x1 | 1985 | none | 110 | 55 | 6 | 2 | 6 | 110 | 155
20 | stadium (N part) | temperate | EDGE ... INNER_SUBURB | SIZE_2x2 | 1930 | none | 65 | 5 | 4 | 0 | 0 | 300 | 250
21 | stadium (E part) |  |  | N/A | 1930 | none | 0 | 5 | 4 | 0 | 0 | 300 | 250
22 | stadium (W part) |  |  | N/A | 1930 | none | 0 | 5 | 4 | 0 | 0 | 300 | 250
23 | stadium (S part) |  |  | N/A | 1930 | none | 0 | 5 | 4 | 0 | 0 | 300 | 250
24 | old houses | temperate | EDGE, OUTSKIRT | SIZE_1x1 | 1930 | 1951 | 15 | 6 | 3 | 1 | 0 | 75 | 70
25 | cottages | temperate | EDGE | SIZE_1x1 | 1930 | 1952 | 12 | 7 | 3 | 1 | 0 | 75 | 75
26 | houses | temperate | EDGE ... INNER_SUBURB | SIZE_1x1 | 1931 | none | 13 | 8 | 3 | 1 | 0 | 75 | 71
27 | flats | temperate | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1935 | none | 100 | 35 | 7 | 2 | 2 | 100 | 135
28 | tall office block | temperate | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1963 | none | 170 | 50 | 8 | 3 | 3 | 170 | 145
29 | shops and offices | temperate | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | 1955 | 100 | 40 | 6 | 2 | 3 | 135 | 132
30 | shops and offices | temperate, subtropical | OUTER_SUBURB, CENTRE | SIZE_1x1 | 1973 | none | 180 | 64 | 8 | 3 | 3 | 180 | 155
31 | theatre | temperate | INNER_SUBURB, CENTRE | SIZE_1x1 | 1930 | none | 35 | 23 | 8 | 2 | 2 | 230 | 220
32 | stadium (modern style, N part) | temperate, sub-arctic, subtropical | EDGE ... INNER_SUBURB | SIZE_2x2 | 1958 | none | 65 | 5 | 4 | 0 | 0 | 300 | 250
33 | stadium (modern style, E part) |  |  | N/A | 1958 | none | 0 | 5 | 4 | 0 | 0 | 300 | 250
34 | stadium (modern style, W part) |  |  | N/A | 1958 | none | 0 | 5 | 4 | 0 | 0 | 300 | 250
35 | stadium (modern style, S part) |  |  | N/A | 1958 | none | 0 | 5 | 4 | 0 | 0 | 300 | 250
36 | offices ('vertical tube' style) | temperate, sub-arctic, subtropical | INNER_SUBURB, CENTRE | SIZE_1x1 | 2000 | none | 140 | 65 | 8 | 3 | 2 | 250 | 170
37 | houses | sub-arctic | EDGE, OUTSKIRT | SIZE_1x1 | 1930 | 1960 | 15 | 6 | 3 | 1 | -1 | 75 | 70
38 | houses | snow | EDGE, OUTSKIRT | SIZE_1x1 | 1930 | 1960 | 15 | 6 | 3 | 1 | -1 | 75 | 70
39 | cinema | temperate | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1945 | none | 35 | 23 | 8 | 2 | 2 | 230 | 210
40 | shopping mall (N part) | temperate | OUTSKIRT ... CENTRE | SIZE_2x2 | 1983 | none | 180 | 5 | 8 | 2 | 3 | 300 | 250
41 | shopping mall (E part) |  |  | N/A | 1983 | none | 0 | 5 | 8 | 2 | 3 | 300 | 250
42 | shopping mall (W part) |  |  | N/A | 1983 | none | 0 | 5 | 8 | 2 | 3 | 300 | 250
43 | shopping mall (S part) |  |  | N/A | 1983 | none | 0 | 5 | 8 | 2 | 3 | 300 | 250
44 | flats | sub-arctic | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | none | 80 | 20 | 5 | 2 | -2 | 90 | 100
45 | flats | snow | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | none | 80 | 20 | 5 | 2 | -2 | 90 | 100
46 | houses | sub-arctic | EDGE ... INNER_SUBURB | SIZE_1x1 | 1930 | none | 16 | 6 | 3 | 1 | -2 | 70 | 70
47 | houses | snow | EDGE ... INNER_SUBURB | SIZE_1x1 | 1930 | none | 16 | 6 | 3 | 1 | -2 | 70 | 70
48 | houses | sub-arctic | EDGE ... OUTER_SUBURB | SIZE_1x1 | 1930 | 1963 | 14 | 6 | 3 | 1 | -2 | 70 | 80
49 | houses | snow | EDGE ... OUTER_SUBURB | SIZE_1x1 | 1930 | 1963 | 14 | 6 | 3 | 1 | -2 | 70 | 80
50 | tall office block | sub-arctic, subtropical | INNER_OUTSKIRT, CENTRE | SIZE_1x1 | 1966 | none | 135 | 60 | 8 | 3 | 4 | 120 | 150
51 | tall office block | snow | INNER_SUBURB, CENTRE | SIZE_1x1 | 1966 | none | 135 | 60 | 8 | 3 | 4 | 120 | 150
52 | tall office block | sub-arctic | INNER_SUBURB, CENTRE | SIZE_1x1 | 1970 | none | 170 | 70 | 9 | 3 | 4 | 130 | 170
53 | tall office block | snow | INNER_SUBURB, CENTRE | SIZE_1x1 | 1970 | none | 170 | 70 | 9 | 3 | 4 | 130 | 170
54 | tall office block | sub-arctic, subtropical | INNER_SUBURB, CENTRE | SIZE_1x1 | 1974 | none | 210 | 80 | 10 | 3 | 5 | 140 | 200
55 | tall office block | snow | INNER_SUBURB, CENTRE | SIZE_1x1 | 1974 | none | 210 | 80 | 10 | 3 | 5 | 140 | 200
56 | houses | sub-arctic | EDGE | SIZE_1x1 | 1930 | none | 10 | 5 | 2 | 1 | -1 | 60 | 60
57 | houses | snow | EDGE | SIZE_1x1 | 1930 | none | 10 | 5 | 2 | 1 | -1 | 60 | 60
58 | shops and offices | sub-arctic | OUTSKIRT ... CENTRE | SIZE_1x1 | 1930 | none | 25 | 20 | 3 | 1 | -1 | 80 | 100
59 | shops and offices | snow | OUTSKIRT ... CENTRE | SIZE_1x1 | 1930 | none | 25 | 20 | 3 | 1 | -1 | 80 | 100
60 | church | sub-arctic | EDGE ... INNER_SUBURB | SIZE_1x1 | 1930 | none | 6 | 2 | 2 | 0 | 0 | 230 | 85
61 | church | snow | EDGE ... INNER_SUBURB | SIZE_1x1 | 1930 | none | 6 | 2 | 2 | 0 | 0 | 230 | 85
62 | houses | sub-arctic | EDGE ... OUTER_SUBURB | SIZE_1x1 | 1930 | none | 17 | 7 | 3 | 1 | -1 | 80 | 80
63 | houses | snow | EDGE ... OUTER_SUBURB | SIZE_1x1 | 1930 | none | 17 | 7 | 3 | 1 | -1 | 80 | 80
64 | shops and offices | sub-arctic | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | 1960 | 90 | 45 | 6 | 2 | 3 | 110 | 140
65 | shops and offices | snow | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | 1960 | 90 | 45 | 6 | 2 | 3 | 110 | 140
66 | hotel (N part) | sub-arctic | OUTER_SUBURB ... CENTRE | SIZE_1x2 | 1972 | none | 140 | 25 | 6 | 1 | -3 | 160 | 160
67 | hotel (E part) |  |  | N/A | 1972 | none | 0 | 25 | 6 | 1 | 2 | 160 | 160
68 | hotel (N part) | snow | OUTER_SUBURB ... CENTRE | SIZE_1x2 | 1972 | none | 140 | 25 | 6 | 1 | -3 | 160 | 160
69 | hotel (E part) |  |  | N/A | 1972 | none | 0 | 25 | 6 | 1 | 2 | 160 | 160
70 | shops and offices | sub-arctic, subtropical | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1963 | none | 105 | 50 | 7 | 2 | 3 | 105 | 130
71 | shops and offices | snow | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1963 | none | 105 | 50 | 7 | 2 | 3 | 105 | 130
72 | tall office block | sub-arctic | INNER_SUBURB, CENTRE | SIZE_1x1 | 1978 | none | 190 | 75 | 9 | 3 | 4 | 135 | 190
73 | tall office block | snow | INNER_SUBURB, CENTRE | SIZE_1x1 | 1978 | none | 190 | 75 | 9 | 3 | 4 | 135 | 190
74 | tall office block (N part) | sub-arctic | OUTER_SUBURB ... CENTRE | SIZE_2x1 | 1967 | none | 250 | 60 | 7 | 2 | 2 | 200 | 140
75 | tall office block (W part) |  |  | N/A | 1967 | none | 0 | 60 | 7 | 2 | 2 | 200 | 140
76 | tall office block (N part) | snow | OUTER_SUBURB ... CENTRE | SIZE_2x1 | 1967 | none | 250 | 60 | 7 | 2 | 2 | 200 | 140
77 | tall office block (W part) |  |  | N/A | 1967 | none | 0 | 60 | 7 | 2 | 2 | 200 | 140
78 | houses (with a tree in a corner) | subtropical | OUTSKIRT ... CENTRE | SIZE_1x1 | 1930 | none | 16 | 6 | 3 | 1 | -2 | 80 | 80
79 | houses | subtropical | OUTSKIRT ... CENTRE | SIZE_1x1 | 1930 | none | 16 | 6 | 3 | 1 | -2 | 80 | 80
80 | houses | subtropical | OUTSKIRT ... CENTRE | SIZE_1x1 | 1930 | none | 16 | 5 | 3 | 1 | -2 | 80 | 80
81 | houses (suburb-type) | subtropical | EDGE | SIZE_1x1 | 1930 | none | 7 | 4 | 3 | 1 | -1 | 30 | 30
82 | flats | subtropical | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | none | 45 | 15 | 6 | 2 | 1 | 95 | 130
83 | church | subtropical | OUTSKIRT ... INNER_SUBURB | SIZE_1x1 | 1930 | none | 8 | 3 | 2 | 0 | 0 | 200 | 90
84 | houses (with two trees in front) | subtropical | OUTSKIRT ... CENTRE | SIZE_1x1 | 1930 | none | 18 | 7 | 3 | 1 | -2 | 80 | 80
85 | flats | subtropical | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1973 | none | 90 | 24 | 6 | 2 | 1 | 95 | 110
86 | flats | subtropical | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1962 | none | 120 | 25 | 6 | 2 | 1 | 95 | 120
87 | tall office block (N part) | subtropical | INNER_SUBURB, CENTRE | SIZE_2x1 | 1984 | none | 250 | 80 | 8 | 3 | 4 | 140 | 190
88 | tall office block (W part) | subtropical |  | N/A | 1984 | none | 0 | 80 | 8 | 3 | 4 | 140 | 190
89 | flats | subtropical | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | none | 80 | 23 | 6 | 2 | 1 | 95 | 110
90 | tall office block | subtropical | INNER_SUBURB, CENTRE | SIZE_1x1 | 1993 | none | 180 | 90 | 8 | 3 | 4 | 150 | 180
91 | church | toyland | EDGE ... CENTRE | SIZE_1x1 | 1930 | none | 8 | 3 | 2 | 0 | 0 | 200 | 90
92 | toyland houses | toyland | EDGE ... CENTRE | SIZE_1x1 | 1930 | none | 18 | 5 | 6 | 2 | 2 | 90 | 90
93 | toyland houses | toyland | EDGE, OUTSKIRT | SIZE_1x1 | 1930 | none | 7 | 3 | 3 | 1 | 1 | 50 | 70
94 | toyland houses | toyland | EDGE ... INNER_SUBURB | SIZE_1x1 | 1930 | none | 15 | 6 | 3 | 1 | 2 | 75 | 80
95 | toyland houses | toyland | EDGE ... INNER_SUBURB | SIZE_1x1 | 1930 | none | 17 | 6 | 3 | 1 | 2 | 75 | 80
96 | toyland houses | toyland | EDGE ... INNER_SUBURB | SIZE_1x1 | 1930 | none | 19 | 6 | 3 | 1 | 2 | 75 | 80
97 | toyland houses | toyland | EDGE ... INNER_SUBURB | SIZE_1x1 | 1930 | none | 21 | 6 | 3 | 1 | 2 | 75 | 80
98 | tall office block | toyland | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | none | 75 | 20 | 8 | 4 | 2 | 130 | 160
99 | shoe house (N part) | toyland | EDGE ... CENTRE | SIZE_1x2 | 1930 | none | 35 | 9 | 4 | 1 | 2 | 80 | 90
100 | shoe house (E part) |  |  | N/A | 1930 | none | 0 | 0 | 4 | 1 | 2 | 80 | 90
101 | tall office block | toyland | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | none | 85 | 18 | 8 | 4 | 2 | 130 | 150
102 | igloo | toyland | EDGE | SIZE_1x1 | 1930 | none | 11 | 3 | 3 | 1 | 1 | 45 | 60
103 | tepees | toyland | EDGE | SIZE_1x1 | 1930 | none | 10 | 3 | 3 | 1 | 1 | 45 | 60
104 | shops and offices | toyland | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | none | 67 | 22 | 8 | 4 | -4 | 130 | 140
105 | shops and offices | toyland | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | none | 86 | 23 | 8 | 4 | -4 | 130 | 145
106 | tall office block | toyland | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | none | 95 | 28 | 8 | 4 | 2 | 130 | 165
107 | statue | toyland | OUTER_SUBURB ... CENTRE | SIZE_1x1 | 1930 | none | 30 | 10 | 4 | 1 | 2 | 70 | 90
108 | teapot-house | toyland | EDGE ... CENTRE | SIZE_1x1 | 1930 | none | 25 | 8 | 3 | 1 | 2 | 65 | 75
109 | piggy-bank | toyland | EDGE ... CENTRE | SIZE_1x1 | 1930 | none | 18 | 7 | 3 | 2 | -4 | 95 | 85

## List of town zones

TOWNZONE_EDGE
TOWNZONE_OUTSKIRT
TOWNZONE_OUTER_SUBURB
TOWNZONE_INNER_SUBURB
TOWNZONE_CENTRE

## List of tile classes

TILE_CLASS_GROUND | Clear ground and farmland
TILE_CLASS_RAIL | Rail and rail depots
TILE_CLASS_ROAD | Road, road depots and level crossings
TILE_CLASS_HOUSE | Houses
TILE_CLASS_TREES | Clear tile with trees
TILE_CLASS_STATION | Station, waypoint, station part of oilrig
TILE_CLASS_WATER | Sea, canal, ship depot
TILE_CLASS_INDUSTRY | Industry tile
TILE_CLASS_TUNNEL_BRIDGE | Tunnel entrance or bridge ramp
TILE_CLASS_OBJECTS | Objects

## List default colour translation palettes

You can use the palette name directly. The numeric value is only given for reference and might come in handy when the values are to be used in calculations. `PALETTE_USE_DEFAULT` in conjunction with the recolour mode `RECOLOUR_REMAP` uses the normal company (and for NewObjects and airports the 2nd company colour) settings as defined by the player:

Palette name | value
--- | ---
PALETTE_USE_DEFAULT | 0
PALETTE_TILE_RED_PULSATING | 771
PALETTE_SEL_TILE_RED | 772
PALETTE_SEL_TILE_BLUE | 773
PALETTE_CC_FIRST | 775
PALETTE_CC_DARK_BLUE | 775, # = first
PALETTE_CC_PALE_GREEN | 776
PALETTE_CC_PINK | 777
PALETTE_CC_YELLOW | 778
PALETTE_CC_RED | 779
PALETTE_CC_LIGHT_BLUE | 780
PALETTE_CC_GREEN | 781
PALETTE_CC_DARK_GREEN | 782
PALETTE_CC_BLUE | 783
PALETTE_CC_CREAM | 784
PALETTE_CC_MAUVE | 785
PALETTE_CC_PURPLE | 786
PALETTE_CC_ORANGE | 787
PALETTE_CC_BROWN | 788
PALETTE_CC_GREY | 789
PALETTE_CC_WHITE | 790
PALETTE_BARE_LAND | 791
PALETTE_STRUCT_BLUE | 795
PALETTE_STRUCT_BROWN | 796
PALETTE_STRUCT_WHITE | 797
PALETTE_STRUCT_RED | 798
PALETTE_STRUCT_GREEN | 799
PALETTE_STRUCT_CONCRETE | 800
PALETTE_STRUCT_YELLOW | 801
PALETTE_TRANSPARENT | 802
PALETTE_STRUCT_GREY | 803
PALETTE_CRASH | 804
PALETTE_CHURCH_RED | 1438
PALETTE_CHURCH_CREAM | 1439
base_sprite_2cc | n/a

The base sprite for 2 company colours may vary. Following `base_sprite_2cc` are the 16x16 colour translations for all possible combinations of a company colour with an arbitrary 2nd company colour. The order of the colours is the same as for `PALETTE_CC_XX`:

PALETTE_CC_FIRST | PALETTE_CC_FIRST
PALETTE_CC_FIRST | PALETTE_CC_FIRST+1
PALETTE_CC_FIRST | ...
PALETTE_CC_FIRST+1 | PALETTE_CC_FIRST
PALETTE_CC_FIRST+1 | PALETTE_CC_FIRST+1
... | ...
PALETTE_CC_FIRST+15 | PALETTE_CC_FIRST
PALETTE_CC_FIRST+15 | ...
PALETTE_CC_FIRST+15 | PALETTE_CC_FIRST+15

## List of tile slopes

Tiles in TTD can have various slopes. The slope is a 5-bit wide mask:

bit | meaning
--- | ---
0 | west corner is above the lowest corner.
1 | south corner is above the lowest corner.
2 | east corner is above the lowest corner.
3 | north corner is above the lowest corner.
4 | this tile is a steep slope (the corner opposite to the lowest corner is 2 units higher).

The resulting, possible values are 0 ... 14, 23, 27, 29 and 30. Their meaning is illustrated in this image:

## List direction constants

- DIRECTION_NORTH
- DIRECTION_NORTHEAST
- DIRECTION_EAST
- DIRECTION_SOUTHEAST
- DIRECTION_SOUTH
- DIRECTION_SOUTHWEST
- DIRECTION_WEST
- DIRECTION_NORTHWEST